# ApiJob

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Output. Unique run ID. Generated by API server. | [optional] 
**name** | **str** | Required input field. Job name provided by user. Not unique. | [optional] 
**description** | **str** |  | [optional] 
**pipeline_spec** | [**ApiPipelineSpec**](ApiPipelineSpec.md) |  | [optional] 
**resource_references** | [**list[ApiResourceReference]**](ApiResourceReference.md) | Optional input field. Specify which resource this job belongs to. | [optional] 
**service_account** | **str** | Optional input field. Specify which Kubernetes service account this job uses. | [optional] 
**max_concurrency** | **str** |  | [optional] 
**trigger** | [**ApiTrigger**](ApiTrigger.md) |  | [optional] 
**mode** | [**JobMode**](JobMode.md) |  | [optional] 
**created_at** | **datetime** | Output. The time this job is created. | [optional] 
**updated_at** | **datetime** | Output. The last time this job is updated. | [optional] 
**status** | **str** |  | [optional] 
**error** | **str** | In case any error happens retrieving a job field, only job ID and the error message is returned. Client has the flexibility of choosing how to handle error. This is especially useful during listing call. | [optional] 
**enabled** | **bool** | Input. Whether the job is enabled or not. | [optional] 
**no_catchup** | **bool** | Optional input field. Whether the job should catch up if behind schedule. If true, the job will only schedule the latest interval if behind schedule. If false, the job will catch up on each past interval. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


